@@ -1,7 +1,8 @@
-from ._base import AnyThing, IsInstance
-from ._datetime import IsDatetime, IsNow
-from ._dict import IsDict, IsPartialDict, IsStrictDict
-from ._list_tuple import Contains, HasLen, IsList, IsListOrTuple, IsTuple
+from ._base import AnyThing, DirtyEquals, IsOneOf
+from ._boolean import IsFalseLike, IsTrueLike
+from ._datetime import IsDate, IsDatetime, IsNow, IsToday
+from ._dict import IsDict, IsIgnoreDict, IsPartialDict, IsStrictDict
+from ._inspection import HasAttributes, HasName, HasRepr, IsInstance
 from ._numeric import (
     IsApprox,
     IsFloat,
@@ -18,20 +19,28 @@ from ._numeric import (
     IsPositiveInt,
 )
 from ._other import FunctionCheck, IsJson, IsUUID
+from ._sequence import Contains, HasLen, IsList, IsListOrTuple, IsTuple
 from ._strings import IsAnyStr, IsBytes, IsStr
 
 __all__ = (
     # base
+    'DirtyEquals',
     'AnyThing',
-    'IsInstance',
+    'IsOneOf',
+    # boolean
+    'IsTrueLike',
+    'IsFalseLike',
     # datetime
     'IsDatetime',
     'IsNow',
+    'IsDate',
+    'IsToday',
     # dict
     'IsDict',
     'IsPartialDict',
+    'IsIgnoreDict',
     'IsStrictDict',
-    # list or tuple
+    # sequence
     'Contains',
     'HasLen',
     'IsList',
@@ -51,6 +60,11 @@ __all__ = (
     'IsFloat',
     'IsPositiveFloat',
     'IsNegativeFloat',
+    # inspection
+    'HasAttributes',
+    'HasName',
+    'HasRepr',
+    'IsInstance',
     # other
     'FunctionCheck',
     'IsJson',
@@ -63,4 +77,4 @@ __all__ = (
     '__version__',
 )
 
-__version__ = '0.0.5'
+__version__ = '0.2'
